@@ -6,54 +6,64 @@ from lxml import etree
 base_url = 'http://www.yify-torrent.org'
 
 # use semaphore to limit the number of coroutines
-sem = asyncio.Semaphore(10)
+sem = asyncio.Semaphore(15)
 
 
 @asyncio.coroutine
-def get_movie(url):
-    # get movie page
+def get_one(url):
+    '''Get informations of the specific movie.'''
+    # get page content by asyncio
     res = yield from aiohttp.request('GET', url)
     content = yield from res.text()
 
+    movie = {}
+
+    # use lxml to find the informations we want
     root = etree.HTML(content)
 
-    datas = {}
-
     # get movie poster
-    datas['poster_large'] = root.xpath('//div[@class="cover"]/img')[0].attrib['src']
+    movie['poster_large'] =\
+        root.xpath('//div[@class="cover"]/img')[0].attrib['src']
 
     # get movie details
     for li in root.xpath('//div[@class="inattr"]//li'):
-        texts = list(text.lower().strip().replace(' ', '_') for text in li.itertext())
-        key = texts[0].replace(':', '')
-        value = ' '.join(texts[1:]).strip()
-        datas[key] = value
+        # strip space for each text segments
+        texts = list(text.strip() for text in li.itertext())
 
-        # get imdb link
+        # use first segment as key
+        # lowercase, remove : and replace space with underscore
+        key = texts[0].lower().replace(':', '').replace(' ', '_')
+
+        # others as value, and join all as one string
+        value = ' '.join(texts[1:]).strip()
+        movie[key] = value
+
+        # get imdb link if key is imdb_rating
         if key == 'imdb_rating':
-            datas['imdb'] = li.xpath('./a')[0].attrib['href']
+            movie['imdb'] = li.xpath('./a')[0].attrib['href']
 
     attrs = root.xpath('//div[@class="outattr"]/div[@class="attr"]')
     # get trailer
-    datas['trailer'] = attrs[1].xpath('./a')[0].attrib['href']
+    movie['trailer'] = attrs[1].xpath('./a')[0].attrib['href']
     # get magnet
-    datas['magnet'] = attrs[2].xpath('./a')[0].attrib['href']
+    movie['magnet'] = attrs[2].xpath('./a')[0].attrib['href']
 
     # get screenshots
     imgs = root.xpath('//div[@class="scrshot"]//img')
-    datas['screenshot'] = [i.attrib['src'] for i in imgs]
+    movie['screenshot'] = [i.attrib['src'] for i in imgs]
 
     # get plot
-    datas['plot'] = root.xpath('//div[@class="info"]/p')[0].text
+    movie['plot'] = root.xpath('//div[@class="info"]/p')[0].text
 
-    return datas
+    return movie
 
 
 @asyncio.coroutine
 def get_movies(kind, page, search=None):
+    '''Get all movies by specifing kind.'''
+    # use semaphore to limit the number of coroutines
     with (yield from sem):
         url = get_url(kind, page, search)
-
         # check url is None
         if url is None:
             return []
@@ -68,23 +78,15 @@ def get_movies(kind, page, search=None):
         root = etree.HTML(content)
         # every movie is inside a div with class mv
         for mv in root.xpath('//div[@class="mv"]'):
-            # find movie title and yify link
-            h3 = mv.xpath('./h3')
-            a = h3[0].xpath('./a')[0]
+            a = mv.xpath('./h3')[0].xpath('./a')[0]
+            # get movie title
             title = a.text
+            # get yify link
             link = base_url + a.attrib['href']
 
             # find movie poster image
-            poster = mv.xpath('.//div[@class="movie-image"]//img')[0].attrib['src']
-
-            # find movie informations like genre, quality...
-            infos = {}
-            for li in mv.xpath('.//li'):
-                texts = list(text.lower().strip().replace(' ', '_') for text in li.itertext())
-                # remove : for first item, and convert string to lowercase
-                texts[0] = texts[0].replace(':', '').lower()
-                # use first item as key, others as value
-                infos[texts[0]] = ' '.join(texts[1:])
+            poster =\
+                mv.xpath('.//div[@class="movie-image"]//img')[0].attrib['src']
 
             # put movie data into dictionary
             movie = {
@@ -92,17 +94,27 @@ def get_movies(kind, page, search=None):
                 'link': link,
                 'poster_small': poster,
             }
-            movie.update(infos)
+
+            # find movie informations like genre, qualit, etc
+            for li in mv.xpath('.//li'):
+                # strip space for each text segments
+                texts = list(text.strip() for text in li.itertext())
+
+                # use first segment as key
+                # lowercase, remove : and replace space with underscore
+                key = texts[0].lower().replace(':', '').replace(' ', '_')
+
+                # others as value, and join all as one string
+                value = ' '.join(texts[1:]).strip()
+                movie[key] = value
 
             # append movie into movies
             movies.append(movie)
 
-        # get details of each movie by calling get_movie
+        # get informations from the movie's yify link
         for movie in movies:
-            info = yield from get_movie(movie['link'])
-
-            # update movie dictionary with info
-            movie.update(info)
+            detail = yield from get_one(movie['link'])
+            movie.update(detail)
 
         return movies
 
@@ -136,8 +148,8 @@ def search(keyword, page=1):
 
 @asyncio.coroutine
 def test():
-    # get first ten pages of movies
-    for f in asyncio.as_completed([popular(i) for i in range(1, 11)]):
+    '''Get ten pages of movies.'''
+    for f in asyncio.as_completed([popular(i) for i in range(1, 3)]):
         movies = yield from f
         for movie in movies:
             print(movie['rating'], movie['title'])
